@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-import re, cgi, codecs, copy, sys
+import os, re, cgi, codecs, copy, sys
 try:
     import xml.etree.cElementTree as et
 except ImportError:
@@ -16,6 +16,10 @@ from collections import defaultdict
 from optparse import OptionParser
 
 
+# Get current running script folder (MetaPath app folder)
+scriptdir = os.path.realpath(__file__).rpartition('/')[0]
+
+
 # Standard definitions
 et.register_namespace('', 'http://pathvisio.org/GPML/2013a')
 
@@ -72,12 +76,13 @@ def get_styles( o, restyle ):
 def gpml2svg(
     gpml, 
     node_colors = {},
-#    synonyms = {},
     xrefs = {
         'HMDB': 'http://www.hmdb.ca/metabolites/%s',
         'WikiPathways': 'http://wikipathways.org/index.php/Pathway:%s',
         'Entrez Gene': 'http://www.ncbi.nlm.nih.gov/gene/%s',
-    }
+    },
+    xrefs_synonyms = {}, # A conversion dictionary to generate additional XRefs
+    xrefs_classes = ['HMDB','Entrez Gene'], # A list of XRefs to use to generate data node classes (post-coloring/transformations)
     ):
 
 
@@ -539,8 +544,7 @@ def gpml2svg(
         'graphids': graphids,
     }
 
-    template = templateEngine.get_template('gpml2svg.svg')
-
+    template = templateEngine.get_template( os.path.join( scriptdir,'gpml2svg.svg') )
     return template.render( metadata )
 
 def main():
@@ -572,6 +576,5 @@ def main():
     o.write( svg )
     o.close()
 
-
 if __name__ == "__main__":
     main()
\ No newline at end of file
